==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/cs/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Tento uživatel se může přihlásit',
    'activated_disabled_help_text' => 'Nelze upravit stav aktivace pro svůj vlastní účet.',
    'assets_user'       => 'Majetky přiřazené :name',
    'bulk_update_warn'	=> 'Chystáte se upravit vlastnosti :user_count uživatelů. Nezapomeňte, že pomocí tohoto formuláře nemůžete změnit vlastní atributy uživatele a musíte provádět vlastní úpravy individuálně.',
    'bulk_update_help'	=> 'Tento formulář umožňuje aktualizovat více uživatelů najednou. Vyplňte pouze pole, která potřebujete změnit. Všechna pole, která jsou prázdná, zůstanou nezměněny.',
    'current_assets'    => 'Majetky které jsou v současné době vydány uživateli',
    'clone'             => 'Duplikuj uživatele',
    'contact_user'      => 'Kontakt na :name',
    'edit'              => 'Upravit uživatele',
    'filetype_info'     => 'Povolené přílohy: png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Historie:',
	'info'				=> 'Informace',
    'restore_user'		=> 'Klikněte zde pro obnovení.',
    'last_login'        => 'Poslední přihlášení',
    'ldap_config_text'  => 'Nastavení konfigurace LDAP lze nalézt v menu Správce> Nastavení. Vybrané (volitelně) místo bude nastaven pro všechny importované uživatele.',
    'print_assigned'    => 'Vypsat všechna přiřazení',
    'software_user'     => 'Software vydaný pro :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Zobraz uživatele',
    'usercsv'           => 'CSV soubor',
    'two_factor_admin_optin_help' => 'Vaše současná nastavení administrátora umožňují selektivní vynucení dvoufaktorového ověřování.  ',
    'two_factor_enrolled' => 'Přihlášeno zařízení 2FA ',
    'two_factor_active'   => '2FA aktivní ',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/cs/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Tento uživatel se může přihlásit',
    'activated_disabled_help_text' => 'Nelze upravit stav aktivace pro svůj vlastní účet.',
    'assets_user'       => 'Majetky přiřazené :name',
    'bulk_update_warn'	=> 'Chystáte se upravit vlastnosti :user_count uživatelů. Nezapomeňte, že pomocí tohoto formuláře nemůžete změnit vlastní atributy uživatele a musíte provádět vlastní úpravy individuálně.',
    'bulk_update_help'	=> 'Tento formulář umožňuje aktualizovat více uživatelů najednou. Vyplňte pouze pole, která potřebujete změnit. Všechna pole, která jsou prázdná, zůstanou nezměněny.',
    'current_assets'    => 'Majetky které jsou v současné době vydány uživateli',
    'clone'             => 'Duplikuj uživatele',
    'contact_user'      => 'Kontakt na :name',
    'edit'              => 'Upravit uživatele',
    'filetype_info'     => 'Povolené přílohy: png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Historie:',
    'info'				=> 'Informace',
    'restore_user'		=> 'Klikněte zde pro obnovení.',
    'last_login'        => 'Poslední přihlášení',
    'ldap_config_text'  => 'Nastavení konfigurace LDAP lze nalézt v menu Správce> Nastavení. Vybrané (volitelně) místo bude nastaven pro všechny importované uživatele.',
    'print_assigned'    => 'Vypsat všechna přiřazení',
    'software_user'     => 'Software vydaný pro :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Zobraz uživatele',
    'usercsv'           => 'CSV soubor',
    'two_factor_admin_optin_help' => 'Vaše současná nastavení administrátora umožňují selektivní vynucení dvoufaktorového ověřování.  ',
    'two_factor_enrolled' => 'Přihlášeno zařízení 2FA ',
    'two_factor_active'   => '2FA aktivní ',
    'user_deactivated'  => 'Uživatel je deaktivován',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
